@@ -90,7 +90,23 @@ __MERCHANT_CUSTOMER_REWARD_SCHEMA = {
                             bigquery.SchemaField('UpdatedDateTime', 'DATETIME'),
                             }
 
-
+__MERCHANT_CUSTOMER_PREPAID_SCHEMA = {
+                        
+                            bigquery.SchemaField('Key', 'STRING'),
+                            bigquery.SchemaField('CustomerKey', 'STRING'),
+                            bigquery.SchemaField('MerchantKey', 'STRING'),
+                            bigquery.SchemaField('TransactOutlet', 'STRING'),
+                            bigquery.SchemaField('TransactionId', 'STRING'),
+                            bigquery.SchemaField('TransactAmount', 'FLOAT64'),
+                            bigquery.SchemaField('TransactDateTime', 'DATETIME'),
+                            bigquery.SchemaField('TopupAmount', 'FLOAT64'),
+                            bigquery.SchemaField('PrepaidAmount', 'FLOAT64'),
+                            bigquery.SchemaField('ExpiryDate', 'DATE'),
+                            bigquery.SchemaField('TopupDateTime', 'DATETIME'),
+                            bigquery.SchemaField('Reverted', 'BOOLEAN'),
+                            bigquery.SchemaField('RevertedDateTime', 'DATETIME'),
+                            bigquery.SchemaField('UpdatedDateTime', 'DATETIME'),
+                            }
 
 __MERCHANT_CUSTOMER_REDEMPTION_SCHEMA = {
                         
@@ -126,6 +142,7 @@ CUSTOMER_TRANSACTION_TEMPLATE               = 'customer_transaction'
 REGISTERED_MERCHANT_TEMPLATE                = 'registered_merchant'
 MERCHANT_REGISTERED_CUSTOMER_TEMPLATE       = 'merchant_registered_customer'
 MERCHANT_CUSTOMER_REWARD_TEMPLATE           = 'customer_reward'
+MERCHANT_CUSTOMER_PREPAID_TEMPLATE          = 'customer_prepaid'
 MERCHANT_CUSTOMER_REDEMPTION_TEMPLATE       = 'customer_redemption'
     
 
@@ -136,5 +153,6 @@ TABLE_SCHEME_TEMPLATE = {
                     MERCHANT_REGISTERED_CUSTOMER_TEMPLATE   : __MERCHANT_REGISTERED_CUSTOMER_SCHEMA,
                     CUSTOMER_TRANSACTION_TEMPLATE           : __MERCHANT_CUSTOMER_TRANSACTION_SCHEMA,
                     MERCHANT_CUSTOMER_REWARD_TEMPLATE       : __MERCHANT_CUSTOMER_REWARD_SCHEMA,
+                    MERCHANT_CUSTOMER_PREPAID_TEMPLATE      : __MERCHANT_CUSTOMER_PREPAID_SCHEMA,
                     MERCHANT_CUSTOMER_REDEMPTION_TEMPLATE   : __MERCHANT_CUSTOMER_REDEMPTION_SCHEMA,
     }
